about deprecate
================

The deprecate library provides decorators and primitives to support
API deprecation and experimentation.

The goal is to support rich and documenting deprecation of API's
as projects move towards new needs.
